@@ -401,6 +401,7 @@ public class CSVReaderWriter {
 			GDE.getUiNotification().setStatusMessage(Messages.getString(MessageIds.GDE_MSGT0138, new String[] {GDE.FILE_ENDING_CSV, filePath}));
 			writer = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(filePath), encoding));
 			char decimalSeparator = Settings.getInstance().getDecimalSeparator();
+			boolean isTimeFormatAbsolute = Settings.getInstance().isTimeFormatAbsolute();
 
 			df3.setGroupingUsed(false);
 			sb = new StringBuffer();
@@ -412,7 +413,7 @@ public class CSVReaderWriter {
 			log.log(Level.FINE, "written header line = " + sb.toString());  //$NON-NLS-1$
 
 			sb = new StringBuffer();
-			sb.append(Messages.getString(MessageIds.GDE_MSGT0137)).append(separator); // Spannung [V];Strom [A];Ladung [Ah];Leistung [W];Energie [Wh]";
+			sb.append(Messages.getString(isTimeFormatAbsolute ? MessageIds.GDE_MSGT0436 : MessageIds.GDE_MSGT0137)).append(separator); // Spannung [V];Strom [A];Ladung [Ah];Leistung [W];Energie [Wh]";
 			// write the measurements signature
 			int i = 0;
 			if (isRaw) {
@@ -447,8 +448,7 @@ public class CSVReaderWriter {
 			catch (Exception e) {
 				startTime = new Date().getTime();
 			}
-			int recordEntries = recordSet.getRecordDataSize(true);
-			boolean isTimeFormatAbsolute = Settings.getInstance().isTimeFormatAbsolute();
+			int recordEntries = recordSet.getRecordDataSize(false);
 			int progressCycle = 0;
 			GDE.getUiNotification().setProgress(progressCycle);
 
@@ -456,6 +456,7 @@ public class CSVReaderWriter {
 				sb = new StringBuffer();
 				if (isRaw) { // do not change any values
 					String[] row = recordSet.getRawExportRow(i, isTimeFormatAbsolute);
+					row[0].replace(',', decimalSeparator);
 					for (String value : row) {
 						if (value != null)
 							sb.append(value.trim());		
@@ -468,7 +469,7 @@ public class CSVReaderWriter {
 					char currentrGoupingSeparator = Character.valueOf(recordSet.get(0).getDecimalFormat().getDecimalFormatSymbols().getGroupingSeparator());
 	
 					// add time entry
-					sb.append(row[0].replace('.', decimalSeparator).trim()).append(separator);
+					sb.append(row[0].replace(',', decimalSeparator).trim()).append(separator);
 					// add data entries
 					int j = 0;
 					for (final Record record : recordSet.getVisibleAndDisplayableRecordsForTable()) {
